@@ -3,9 +3,9 @@
 
 """
  Monsterz: cute puzzle game
- $Id: monsterz.py 131 2006-05-12 16:35:31Z sam $
+ $Id: monsterz.py 135 2007-12-17 22:04:29Z sam $
 
- Copyright: (c) 2005, 2006 Sam Hocevar <sam@zoy.org>
+ Copyright: (c) 2005 - 2007 Sam Hocevar <sam@zoy.org>
    This program is free software; you can redistribute it and/or
    modify it under the terms of the Do What The Fuck You Want To
    Public License, Version 2, as published by Sam Hocevar. See
@@ -20,11 +20,10 @@ from os.path import join, isdir, isfile, dirname, expanduser
 from os import write, mkdir
 
 # String constants
-VERSION = '0.7.0'
-COPYRIGHT = 'MONSTERZ - COPYRIGHT 2005, 2006 SAM HOCEVAR - MONSTERZ IS ' \
+VERSION = '0.7.1'
+COPYRIGHT = 'MONSTERZ - COPYRIGHT 2005 - 2007 SAM HOCEVAR - MONSTERZ IS ' \
             'FREE SOFTWARE, YOU CAN REDISTRIBUTE IT AND/OR MODIFY IT ' \
-            'UNDER THE TERMS OF THE DO WHAT THE FUCK YOU WANT TO ' \
-            'PUBLIC LICENSE, VERSION 2 - '
+            'UNDER THE TERMS OF THE WTFPL LICENSE, VERSION 2 - '
 
 # Constants
 HAVE_AI = False # broken
@@ -370,6 +369,17 @@ class Data:
         x, y = coord
         return ((x - 24) / ITEM_SIZE, (y - 24) / ITEM_SIZE)
 
+class Sprite:
+    def __init__(self, surf, coord):
+        self.surf = surf
+        self.coord = coord
+
+    def set_surf(self, surf):
+        return
+
+    def set_coord(self, coord):
+        return
+
 class System:
     def __init__(self):
         if settings.get('fullscreen'):
